Derive macros for the Doco testing framework
Doco is a test runner and library for writing end-to-tests of web applications. It runs tests in isolated, ephemeral environments. This crate provides procedural macros to make it easier to set up the test runner, collect all tests, and then run them individually in isolated, ephemeral environments.
It is not recommended to use this crate directly. Instead, use the [doco] crate that
re-exports the macros from this crate.